@@ -5,10 +5,12 @@ class UrlsManager(object):
 
     instrospector = Introspector()
 
-    def __init__(self, urlpatterns, views_root):
+    def __init__(self, urlpatterns, views_root, namespace=None):
 
         self.urlpatterns = urlpatterns
         self.views_root = views_root
+        self.namespace = namespace
+
         self.add_views()
 
     def add_views(self):
@@ -17,6 +19,9 @@ class UrlsManager(object):
 
         for view in views:
 
+            if not "namespace" in view.__dict__ and self.namespace is not None:
+                view.namespace = self.namespace
+
             django_urls = self.instrospector.get_django_urls(view)
 
             for url in django_urls:
